@@ -15,7 +15,7 @@ from datetime import datetime
 from flask import _request_ctx_stack, Config, Flask, g, json
 from functools import wraps
 from re import match
-from urllib2 import Request, urlopen
+from urllib2 import Request, urlopen, URLError
 from werkzeug import Headers
 from werkzeug.debug import tbtools
 from zlib import compress
@@ -122,8 +122,7 @@ class Exceptional(object):
         
         @app.route("/exception")
         def exception():
-            message = "Congratulations! Your application is configured \
-                       for Exceptional error tracking."
+            message = "Congratulations! Your application is configured for Exceptional error tracking."
                 
             raise Exception(message)
         
@@ -175,7 +174,7 @@ class Exceptional(object):
         :param context: The current application context.
         """
         traceback = tbtools.get_current_traceback()
-        data = json.dumps({
+        error_data = json.dumps({
             "application_environment": self.__get_application_data(context.app),
             "client": context.app.extensions["exceptional"],
             "request": self.__get_request_data(context.app, context.request, context.session),
@@ -183,18 +182,25 @@ class Exceptional(object):
         })
         
         if context.app.testing:
-            g.exceptional = data
+            g.exceptional = error_data
         
         if self.url:
             request = Request(self.url)
             request.add_header("Content-Type", "application/json")
             
-            if not context.app.debug:
-                request.add_header("Content-Encoding", "deflate")    
-                data = compress(data, 1)
+            if context.app.debug:
+                data = error_data
+            else:
+                request.add_header("Content-Encoding", "deflate")
+                data = compress(error_data, 1)
             
-            urlopen(request, data)
-    
+            try:
+                urlopen(request, data)
+            except URLError:
+                message = "Unable to connect to {0}. See \
+http://status.getexceptional.com for details. Error data:\n{1}".format(self.url, error_data)
+                self.app.logger.warning(message, exc_info=True)
+
     @staticmethod
     def __filter(app, data, filter_name):
         """Filter sensitive data.
